<?php

namespace Drupal\copyscape\Controller;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Database\Connection;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Returns responses for copyscape routes.
 */
class ResultsController extends ControllerBase implements ContainerInjectionInterface {

  /**
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * Constructs a ResultsController object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $dateFormatter
   *   The date formatter.
   */
  public function __construct(
    Connection $database,
    DateFormatterInterface $dateFormatter
  ) {
    $this->database = $database;
    $this->dateFormatter = $dateFormatter;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('date.formatter')
    );
  }

  /**
   * Provides the copyscape results.
   *
   * @return array
   */
  public function results() {
    $query = $this->database->select('copyscape_results', 'cp')
      ->fields('cp', array('nid', 'response', 'created'))
      ->orderBy('created', 'DESC');

    $results = $query->execute()
      ->fetchAll();

    if (empty($results)) {
      // No copyscape results in the database.
      return [
        '#markup' => t('There are no copyscape results in the database at the moment.'),
      ];
    }

    // Build the header.
    $header = array(t('Node ID'), t('Result'), t('Updated'));

    // Build the table fields.
    $rows = array();
    foreach ($results as $row) {
      $response = unserialize($row->response);

      if (empty($response['result'])) {
        $percentage = t('No results found');
      }
      else {
        $percentage = '';
        foreach ($response['result'] as $value) {
          if (!empty($value['percentmatched'])) {
            $percentage .= $value['url'] . ' ' . $value['percentmatched'] . '%<br />';
          }
        }

        $percentage = Xss::filter($percentage);
      }

      $rows[] = array(
        $row->nid,
        $percentage,
        $this->dateFormatter->format($row->created, 'short'),
      );
    }

    return array(
      '#theme' => 'table',
      '#header' => $header,
      '#rows'   => $rows,
    );
  }

}
